@@ -14,9 +14,9 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 import datetime
+import sys
 import os
 import re
-import sys
 from fabric.api import (hide, local, env, execute, abort, lcd, sudo, run, cd, puts, settings as fab_settings)
 from fabric.colors import red, green, yellow, cyan
 from fabric.contrib import django as fab_django
@@ -25,6 +25,7 @@ from fabric.contrib.files import exists as remote_exists
 from fabric.decorators import task, roles
 from fabric.state import output as output_level
 from fabric.utils import error
+
 from eggplant.utils import SettingsDict
 from eggplant.utils.fab import lsudo, virtual_env, fab_argument
 from eggplant.utils.filesystem import temporary_directory, rsync, render_file
@@ -37,6 +38,7 @@ env.roledefs.update({
 
 # Private Functions
 
+
 def deploy_setting(project_name=None, deploy_settings_path=None, **setting_patches):
     """Get deploy_settings.
 
@@ -60,10 +62,12 @@ def deploy_setting(project_name=None, deploy_settings_path=None, **setting_patch
         deploy_settings_path = getattr(env, 'deploy_settings', None)
     if deploy_settings_path is None:
         deploy_settings_path = os.path.abspath(os.path.join(os.getcwd(), 'deploy_settings.py'))
-        if not os.path.exists(deploy_settings_path): deploy_settings_path = None
+        if not os.path.exists(deploy_settings_path):
+            deploy_settings_path = None
     if deploy_settings_path is None and project_name is not None:
         deploy_settings_path = os.path.abspath(os.path.join(os.getcwd(), project_name, 'deploy_settings.py'))
-        if not os.path.exists(deploy_settings_path): deploy_settings_path = None
+        if not os.path.exists(deploy_settings_path):
+            deploy_settings_path = None
     if deploy_settings_path is None:
         print error(red('Cannot find deploy settings', bold=True))
 
@@ -87,6 +91,7 @@ def deploy_setting(project_name=None, deploy_settings_path=None, **setting_patch
 
 # Tasks
 
+
 @task(default=True)
 def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
            verbose=0, update_apache_conf=False, **additional_settings):
@@ -118,19 +123,20 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
 
     # Get deploy settings and project name
     global gitignores, pyc_pattern, raw_gitignores, project_src_root_gitignore
-    execute(deploy_setting, project_name=project_name,
-        deploy_settings_path=deploy_settings_path, **additional_settings)
+    execute(
+        deploy_setting, project_name=project_name, deploy_settings_path=deploy_settings_path, **additional_settings
+    )
     project_name = env.project_name
     deploy_settings = env.deploy_settings
     env.update_apache_conf = update_apache_conf
 
     # Check output level
     env.verbose = verbose = int(verbose)
-    if verbose==0:
+    if verbose == 0:
         hide_output_status = ['everything']
-    elif verbose==1:
+    elif verbose == 1:
         hide_output_status = ['status', 'stdout', 'stderr']
-    elif verbose==2:
+    elif verbose == 2:
         hide_output_status = ['status']
     else:
         hide_output_status = []
@@ -141,14 +147,15 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
     env.use_ssh_config = deploy_settings.get('USE_SSH_CONFIG')
 
     # Load web servers
-    if len(env.roledefs['web_servers'])==0:
+    if len(env.roledefs['web_servers']) == 0:
         with hide('everything'):
             execute('server.web_server', *deploy_settings.get('WEB_SERVERS'))
-            if verbose!=0: puts('')
-    if len(env.roledefs['web_servers'])==0:
+            if verbose != 0:
+                puts('')
+    if len(env.roledefs['web_servers']) == 0:
         abort('Where do you want to deploy to?')
 
-    with temporary_directory(prefix='deploy~%s~'%project_name) as tmp_directory:
+    with temporary_directory(prefix='deploy~%s~' % project_name) as tmp_directory:
         env.tmp_directory = tmp_directory
         # Copy codebase
         puts(cyan('Copy your codebase to temp directory'))
@@ -157,43 +164,44 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
         copy_codebase_rsync_args = '-a --delete --exclude .git'
         ignore_file_list = deploy_settings.get('IGNORE_FILE_LIST', os.path.join(original_src_root, '.gitignore'))
         if ignore_file_list is not None and os.path.exists(ignore_file_list):
-            copy_codebase_rsync_args += ' --exclude-from \'%s\''%os.path.relpath(ignore_file_list, os.getcwd())
-        if not original_src_root.endswith('/'): original_src_root += '/'
-        local('rsync %s %s %s'%(
-            copy_codebase_rsync_args,
-            original_src_root + ('' if original_src_root.endswith('/') else '/'),
-            tmp_directory
-            )
-        )
+            copy_codebase_rsync_args += ' --exclude-from \'%s\'' % os.path.relpath(ignore_file_list, os.getcwd())
+        if not original_src_root.endswith('/'):
+            original_src_root += '/'
+        local('rsync %s %s %s' % (
+            copy_codebase_rsync_args, original_src_root + ('' if original_src_root.endswith('/') else '/'),
+            tmp_directory))
         # Set project source root and append to PYTHONPATH
         env.project_src_root = project_src_root = tmp_directory
         sys.path = [project_src_root] + sys.path
-        if verbose!=0: puts('')
+        if verbose != 0:
+            puts('')
 
         with lcd(tmp_directory):
             # Switch settings
-            project_settings_module = deploy_settings.get('PROJECT_SETTINGS', '%s.settings'%project_name)
-            env.project_settings_path = project_settings_path = project_settings_module.replace('.', '/')+'.py'
+            project_settings_module = deploy_settings.get('PROJECT_SETTINGS', '%s.settings' % project_name)
+            env.project_settings_path = project_settings_path = project_settings_module.replace('.', '/') + '.py'
             # Use symbolic link or not?
-            use_symbolic_link_settings = deploy_settings.get('USE_SYMBOLIC_LINK_SETTINGS',
-                os.path.islink(project_settings_path))
+            use_symbolic_link_settings = deploy_settings.get(
+                'USE_SYMBOLIC_LINK_SETTINGS', os.path.islink(project_settings_path)
+            )
             if use_symbolic_link_settings:
                 # Relink to production one
                 puts(cyan('Move to production settings'))
-                production_settings_module = deploy_settings.get('PRODUCTION_SETTINGS',
-                    '%s.production_settings'%project_name)
-                production_settings_path = production_settings_module.replace('.', '/')+'.py'
-                local('rm -rf %s'%project_settings_path)
-                local('ln -s %s %s'%(
+                production_settings_module = deploy_settings.get(
+                    'PRODUCTION_SETTINGS', '%s.production_settings' % project_name
+                )
+                production_settings_path = production_settings_module.replace('.', '/') + '.py'
+                local('rm -rf %s' % project_settings_path)
+                local('ln -s %s %s' % (
                     os.path.relpath(production_settings_path, os.path.dirname(project_settings_path)),
-                    project_settings_path
-                    )
+                    project_settings_path)
                 )
 
             # load django in
             fab_django.settings_module(project_settings_module)
             from django.conf import settings as django_settings
             from django.core.management import get_commands
+
             env.django_settings = django_settings
 
             # Set paths
@@ -203,15 +211,15 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
             # Get Project Information
             print ''
             print cyan('Project Information:')
-            print 'Project Name:    '+green(project_name)
+            print 'Project Name:    ' + green(project_name)
             print 'Deploy Target:'
-            print '    Host:      '+yellow(', '.join(env.roledefs['web_servers']))
-            print '    Path:      '+yellow(remote_base_path)
+            print '    Host:      ' + yellow(', '.join(env.roledefs['web_servers']))
+            print '    Path:      ' + yellow(remote_base_path)
             print 'Database: (default one)'
-            print '    Engine:    '+yellow(django_settings.DATABASES['default']['ENGINE'])
-            print '    Name:      '+yellow(django_settings.DATABASES['default']['NAME'])
-            print '    Host:      '+yellow(django_settings.DATABASES['default']['HOST'] or 'localhost')
-            print '    User:      '+yellow(django_settings.DATABASES['default']['USER'])
+            print '    Engine:    ' + yellow(django_settings.DATABASES['default']['ENGINE'])
+            print '    Name:      ' + yellow(django_settings.DATABASES['default']['NAME'])
+            print '    Host:      ' + yellow(django_settings.DATABASES['default']['HOST'] or 'localhost')
+            print '    User:      ' + yellow(django_settings.DATABASES['default']['USER'])
             print ''
 
             # Check TODOs and FIX_MEs
@@ -221,9 +229,12 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
                 check_note = deploy_settings.get('CHECK_NOTE')
                 check_fix_me = deploy_settings.get('CHECK_FIX_ME')
                 comment_types = []
-                if check_todo: comment_types += ['TODO']
-                if check_note: comment_types += ['NOTE']
-                if check_fix_me: comment_types += ['FIXME']
+                if check_todo:
+                    comment_types += ['TODO']
+                if check_note:
+                    comment_types += ['NOTE']
+                if check_fix_me:
+                    comment_types += ['FIXME']
                 grep_commands = []
                 comment_styles = [
                     ('# %s:', ['*.py', ]),
@@ -235,15 +246,16 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
                     for comment_style, file_types in comment_styles:
                         for file_type in file_types:
                             comment_string = comment_style % comment_type
-                            grep_commands += ["grep '%s' -n -r %s --include=%s"%(
-                                comment_string, project_src_root, file_type
-                            )]
+                            grep_commands += [
+                                "grep '%s' -n -r %s --include=%s" % (comment_string, project_src_root, file_type)
+                            ]
                 comment_search_results = []
                 for grep_command in grep_commands:
                     local_results = []
                     with fab_settings(hide('everything'), warn_only=True):
                         result = local(grep_command, capture=True)
-                        if len(result): local_results += [result]
+                        if len(result):
+                            local_results += [result]
                     for raw_result in local_results:
                         result_components = raw_result.split(':')
                         path = os.path.relpath(result_components[0], project_src_root)
@@ -251,9 +263,9 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
                         content = ':'.join(result_components[2:]).strip()
                         comment_search_results += [(path, line_number, content)]
                 for path, line_number, content in comment_search_results:
-                    print 'Line %s at %s: %s'%(yellow(line_number), yellow(path, bold=True), content)
-                if len(comment_search_results)==0:
-                    print 'No comment mentioned about %s'%comment_types
+                    print 'Line %s at %s: %s' % (yellow(line_number), yellow(path, bold=True), content)
+                if len(comment_search_results) == 0:
+                    print 'No comment mentioned about %s' % comment_types
                 print ''
 
             # Ask
@@ -267,7 +279,7 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
 
             # Replace gitignore. We wanna preserve pyc
             project_src_root_gitignore = os.path.join(project_src_root, '.gitignore')
-            pyc_pattern = re.compile(r'.*\.py[c|o|\[co\]]$')
+            pyc_pattern = re.compile(r'.*\.py[c|o]$')
             gitignores = []
             with open(project_src_root_gitignore, 'r') as f:
                 raw_gitignores = f.read().strip().split('\n')
@@ -279,7 +291,7 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
                 'logs/',
             ]
             gitignores = set([item for item in gitignores if item])
-            processed_gitignore_content = '\n'.join(list(set(gitignores)))+'\n'
+            processed_gitignore_content = '\n'.join(list(set(gitignores))) + '\n'
             with open(project_src_root_gitignore, 'w') as f:
                 f.write(processed_gitignore_content)
 
@@ -292,11 +304,12 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
                     if 'compress' in get_commands():
                         # django-compressor
                         local('python manage.py compress')
-                if verbose!=0: puts('')
+                if verbose != 0:
+                    puts('')
 
             # Go!
             print cyan('Send codebase to remote servers')
-            print 'Remote: %s'%env.roledefs['web_servers']
+            print 'Remote: %s' % env.roledefs['web_servers']
             print ''
             # Save arguments
             env.commit_msg = commit_msg
@@ -305,6 +318,7 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
             # Clean up
             print green('Deploy finished', bold=True)
 
+
 @roles('web_servers')
 def deploy_to_remote():
     """This is the private core task who really do deploy to web servers.
@@ -312,8 +326,10 @@ def deploy_to_remote():
     """
     # local inner function
     def print_title(title):
-        if verbose==0: print title
-        else: print cyan(title)
+        if verbose == 0:
+            print title
+        else:
+            print cyan(title)
 
     # Get variables
     remote_base_path = env.remote_base_path
@@ -359,41 +375,42 @@ def deploy_to_remote():
     # Get env
     with hide('everything'):
         remote_user = target_run('whoami', **capture_output)
-        remote_group = target_run('id -g -n %s'%remote_user, **capture_output)
+        remote_group = target_run('id -g -n %s' % remote_user, **capture_output)
 
-    print(yellow('Deploy to %s'%host_string, bold=True))
+    print(yellow('Deploy to %s' % host_string, bold=True))
 
     # Make room for deploy target
-    puts('Deploy target is: %s'%remote_base_path)
+    puts('Deploy target is: %s' % remote_base_path)
     if not target_file_existence(remote_base_path):
         print(yellow('Deploy target doesn\'t exist. Create one now.'))
-        target_sudo('mkdir -p %s'%remote_base_path)
-        target_sudo('chmod o+rx %s'%remote_base_path)
+        target_sudo('mkdir -p %s' % remote_base_path)
+        target_sudo('chmod o+rx %s' % remote_base_path)
 
     # Init project
     if not target_file_existence(remote_project_path):
         print(yellow('First time deploy, create git repository:'))
         update_apache_conf = True
         # Make room
-        target_sudo('mkdir -p %s'%remote_project_path)
-        target_sudo('mkdir -p %s'%remote_project_log_root)
-        target_sudo('chown -R %s:%s %s'%(remote_user, remote_group, remote_project_path))
+        target_sudo('mkdir -p %s' % remote_project_path)
+        target_sudo('mkdir -p %s' % remote_project_log_root)
+        target_sudo('chown -R %s:%s %s' % (remote_user, remote_group, remote_project_path))
         # Source folder with git
-        target_run('mkdir -p %s'%remote_project_source_root)
+        target_run('mkdir -p %s' % remote_project_source_root)
         with target_cd(remote_project_path):
             target_run('git init')
             target_run('echo "# ignore files" >> .gitignore')
             target_run('git add .gitignore && git commit -m "Init commit"')
-        # Virtualenv
+            # Virtualenv
         puts(yellow('First time deploy, initialize virtualenv:'))
         with target_cd(remote_project_path):
-            target_run('virtualenv %s'%venv_name)
+            target_run('virtualenv %s' % venv_name)
 
     # Install apache conf
-    wsgi_script_dir_name = deploy_settings.get('WSGI_SCRIPT_DIR_NAME',
-        os.path.join(remote_project_source_root, project_name))
+    wsgi_script_dir_name = deploy_settings.get(
+        'WSGI_SCRIPT_DIR_NAME', os.path.join(remote_project_source_root, project_name)
+    )
     wsgi_script_file_name = deploy_settings.get('WSGI_SCRIPT_FILE_NAME')
-    apache_conf_tmp_name = 'apache~%s.conf'%host_name
+    apache_conf_tmp_name = 'apache~%s.conf' % host_name
     if deploy_settings.get('INSTALL_APACHE_CONF') and update_apache_conf:
         puts(cyan('Generate configuration file of mod_wsgi and Apache'))
         # Get Apache conf template
@@ -410,10 +427,10 @@ def deploy_to_remote():
                 os.path.dirname(__file__),
                 'deploy/%s' % apache_conf_template_filename
             )
-        # Make context for apache conf
+            # Make context for apache conf
         with hide('everything'):
             raw_python_version = target_run('python -c "import sys; print sys.version_info"', **capture_output)
-            python_version = map(lambda x:x.strip().replace('\'', ''), raw_python_version[1:-1].split(','))
+            python_version = map(lambda x: x.strip().replace('\'', ''), raw_python_version[1:-1].split(','))
         default_site_packages = os.path.join(
             remote_project_venv,
             'lib/python%s.%s/site-packages' % (python_version[0], python_version[1])
@@ -457,52 +474,52 @@ def deploy_to_remote():
     # Send codebase
     print_title('Copy project codebase to remote')
     # Clean old pyc
-    target_run('find %s -name \'*.pyc\' -exec rm -rf {} \;'%remote_project_source_root)
+    target_run('find %s -name \'*.pyc\' -exec rm -rf {} \;' % remote_project_source_root)
     # Do rsync
     rsync_argument = '-DLprtz --delete --delete-excluded --exclude \'*.pyc\' --exclude-from \'.gitignore\''
-    if verbose==3: rsync_argument += ' -v'
+    if verbose == 3:
+        rsync_argument += ' -v'
     local(rsync(
         project_src_root + ('' if project_src_root.endswith('/') else '/'),
-        (host_string+':' if is_remote else '') + remote_project_source_root,
-        rsync_argument=rsync_argument
-    ))
+        (host_string + ':' if is_remote else '') + remote_project_source_root, rsync_schema=rsync_argument))
 
     # Setup Remote
     if deploy_settings.get('RUN_REMOTE_SETUP'):
-        remote_setup_path = deploy_settings.get('REMOTE_SETUP_SCRIPT',
-            os.path.join(remote_project_source_root, project_name, 'remote_setup.py'))
+        remote_setup_path = deploy_settings.get(
+            'REMOTE_SETUP_SCRIPT', os.path.join(remote_project_source_root, project_name, 'remote_setup.py')
+        )
         print(cyan('Setup remote'))
         if target_file_existence(remote_setup_path):
-            target_run('chmod u+x %s'%remote_setup_path)
+            target_run('chmod u+x %s' % remote_setup_path)
             remote_setup_dir, remote_setup_filename = os.path.split(remote_setup_path)
             with target_cd(remote_setup_dir):
-                target_run('./%s'%remote_setup_filename)
-            target_run('chmod u-x %s'%remote_setup_path)
+                target_run('./%s' % remote_setup_filename)
+            target_run('chmod u-x %s' % remote_setup_path)
         else:
             print(yellow('Cannot find remote setup script'))
 
     # Copy gitignore
     with target_cd(remote_project_path):
-        target_run(rsync('%s/.gitignore'%source_root_name, '.gitignore'))
+        target_run(rsync('%s/.gitignore' % source_root_name, '.gitignore'))
 
     # Install venv
     if deploy_settings.get('CHECK_PIP_REQUIREMENTS'):
         print_title('Install/Upgrade python packages for your project (virtualenv)')
         with fab_settings(virtual_env(remote_project_venv), target_cd(remote_project_path)):
-            target_run('pip install -r %s/requirements.txt'%source_root_name)
+            target_run('pip install -r %s/requirements.txt' % source_root_name)
 
     # Add timestamp in wsgi.py
     wsgi_path = os.path.join(wsgi_script_dir_name, wsgi_script_file_name)
-    target_run('echo "# " >> %s'%wsgi_path)
-    target_run('echo "# Deploy at: %s" >> %s'%(datetime.datetime.now().strftime('%s.%f'), wsgi_path))
+    target_run('echo "# " >> %s' % wsgi_path)
+    target_run('echo "# Deploy at: %s" >> %s' % (datetime.datetime.now().strftime('%s.%f'), wsgi_path))
 
     # Compile python
     if deploy_settings.get('COMPILE_PYC'):
         clean_py = deploy_settings.get('CLEAN_PY_IN_REMOTE')
         print_title('Compile Python bytecode')
-        target_run('python -m compileall -q %s'%remote_project_source_root)
+        target_run('python -m compileall -q %s' % remote_project_source_root)
         if clean_py:
-            target_run('find %s -name \'*.py\' -exec rm -rf {} \;'%remote_project_source_root)
+            target_run('find %s -name \'*.py\' -exec rm -rf {} \;' % remote_project_source_root)
 
     # DB migrate
     with fab_settings(virtual_env(remote_project_venv), target_cd(remote_project_source_root)):
@@ -514,19 +531,16 @@ def deploy_to_remote():
     if deploy_settings.get('INSTALL_APACHE_CONF') and update_apache_conf:
         print(cyan('Install apache conf'))
         apache_conf_path = deploy_settings.get('APACHE_CONF_DIR')
-        apache_conf_target = os.path.join(apache_conf_path, '%s.conf'%project_name)
+        apache_conf_target = os.path.join(apache_conf_path, '%s.conf' % project_name)
         print cyan('Installing Apache conf')
         with target_cd(remote_project_source_root):
-            target_sudo('mv %s %s'%(
-                apache_conf_tmp_name,
-                apache_conf_target
-            ))
+            target_sudo('mv %s %s' % (apache_conf_tmp_name, apache_conf_target))
         apache_conf_updated = True
 
     # Commit git
     puts(cyan('Update project record and commit repository'))
     with fab_settings(target_cd(remote_project_path), hide('warnings'), warn_only=True):
-        target_run('git add -A && git commit -m "%s"'%commit_msg)
+        target_run('git add -A && git commit -m "%s"' % commit_msg)
 
     if deploy_settings.get('RESTART_APACHE') or apache_conf_updated:
         print(cyan('Restarting Apache HTTP Server'))
