@@ -22,8 +22,8 @@ class TimestampModel(models.Model):
     Add 2 time fields (create and modify) into model
     """
 
-    createTime = models.DateTimeField(auto_now_add=True)
-    modifyTime = models.DateTimeField(auto_now=True)
+    create_time = models.DateTimeField(auto_now_add=True)
+    modify_time = models.DateTimeField(auto_now=True)
 
     class Meta:
-        abstract = True
\ No newline at end of file
+        abstract = True
